/***************************************************************************/
/*                                                                         */
/*  ft2test/test_FT_Library_Version.c                                      */
/*                                                                         */
/*    test fixtures for FT_Library_Version                                 */
/*                                                                         */
/*  Copyright 2005 by David Somers                                         */
/*                                                                         */
/*  This file is part of the FreeType project, and may only be used,       */
/*  modified, and distributed under the terms of the FreeType project      */
/*  license, LICENSE.TXT.  By continuing to use, modify, or distribute     */
/*  this file you indicate that you have read the license and              */
/*  understand and accept it fully.                                        */
/*                                                                         */
/***************************************************************************/

#include <ft2build.h>
#include FT_FREETYPE_H

#include <embUnit/embUnit.h>

FT_Library ftlibrary;

static void setUp(void)
{
	FT_Init_FreeType(&ftlibrary);
}

static void tearDown(void)
{
	FT_Done_FreeType(ftlibrary);
}


void test_ft_library_version_BadLibrary(void)
{
	FT_Int va, vb, vc;
	
	va=vb=vc=-1;
	FT_Library_Version(NULL, &va, &vb, &vc);

	TEST_ASSERT_EQUAL_INT(va, 0);
	TEST_ASSERT_EQUAL_INT(vb, 0);
	TEST_ASSERT_EQUAL_INT(vc, 0);

}	

void test_ft_library_version_JunkLibrary(void)
{	
	FT_Int va, vb, vc;
	FT_Library uninitlibrary;
	
	memset(&uninitlibrary, -1, sizeof(FT_Library));

	va=vb=vc=-1;
	FT_Library_Version(uninitlibrary, &va, &vb, &vc);

	TEST_ASSERT_EQUAL_INT(va, 0);
	TEST_ASSERT_EQUAL_INT(vb, 0);
	TEST_ASSERT_EQUAL_INT(vc, 0);
}

void test_ft_library_version_BadParams(void)
{
	FT_Int va, vb, vc;

	va=vb=vc=-1;
	FT_Library_Version(ftlibrary, NULL, &vb, &vc);
	TEST_ASSERT_EQUAL_INT(va, -1);
	TEST_ASSERT_EQUAL_INT(vb, FREETYPE_MINOR);
	TEST_ASSERT_EQUAL_INT(vc, FREETYPE_PATCH);

	va=vb=vc=-1;
	FT_Library_Version(ftlibrary, &va, NULL, &vc);
	TEST_ASSERT_EQUAL_INT(va, FREETYPE_MAJOR);
	TEST_ASSERT_EQUAL_INT(vb, -1);
	TEST_ASSERT_EQUAL_INT(vc, FREETYPE_PATCH);

	va=vb=vc=-1;
	FT_Library_Version(ftlibrary, &va, &vb, NULL);
	TEST_ASSERT_EQUAL_INT(va, FREETYPE_MAJOR);
	TEST_ASSERT_EQUAL_INT(vb, FREETYPE_MINOR);
	TEST_ASSERT_EQUAL_INT(vc, -1);
}

void test_ft_library_version_Query(void)
{
	FT_Int va, vb, vc;

	FT_Library_Version(ftlibrary, &va, &vb, &vc);

	TEST_ASSERT_EQUAL_INT(va, FREETYPE_MAJOR);
	TEST_ASSERT_EQUAL_INT(vb, FREETYPE_MINOR);
	TEST_ASSERT_EQUAL_INT(vc, FREETYPE_PATCH);
}

TestRef TEST_FT_Library_Version(void)
{
	EMB_UNIT_TESTFIXTURES(fixtures)
	{
		new_TestFixture("bad library", test_ft_library_version_BadLibrary),
//		new_TestFixture("junk library", test_ft_library_version_JunkLibrary),
		new_TestFixture("bad params",	test_ft_library_version_BadParams),
		new_TestFixture("sane", test_ft_library_version_Query),
	};
	EMB_UNIT_TESTCALLER(SetLibraryVersionTest, "FT_Library_Version", setUp, tearDown, fixtures);

	/*lint -save -e(740) */
	return (TestRef) & SetLibraryVersionTest;
	/*lint -restore */
}

