/***************************************************************************/
/*                                                                         */
/*  ft2test/test_new_face.c                                                */
/*                                                                         */
/*    test fixtures for FT_New_Face                                        */
/*                                                                         */
/*  Copyright 2005 by David Somers                                         */
/*                                                                         */
/*  This file is part of the FreeType project, and may only be used,       */
/*  modified, and distributed under the terms of the FreeType project      */
/*  license, LICENSE.TXT.  By continuing to use, modify, or distribute     */
/*  this file you indicate that you have read the license and              */
/*  understand and accept it fully.                                        */
/*                                                                         */
/***************************************************************************/

#include <ft2build.h>
#include FT_FREETYPE_H

#include <embUnit/embUnit.h>

FT_Library ftlibrary;
FT_Error fterr;

static void setUp(void)
{
	FT_Init_FreeType(&ftlibrary);
}

static void tearDown(void)
{
	FT_Done_FreeType(ftlibrary);
}

void test_ft_newface_noexistfile(void)
{
	FT_Face face;
	/* attempt to load a non-existant file */
	fterr=FT_New_Face(ftlibrary, "I_Do_Not_Exist", 0, &face);
	/* failure is expected */
	TEST_ASSERT(fterr!=0);
}

void test_ft_newface_ok(void)
{
	FT_Face face;
	fterr=FT_New_Face(ftlibrary, "/usr/share/fonts/TTF/Vera.ttf", 0, &face);
	TEST_ASSERT(fterr==0);
	FT_Done_Face(face);
}

void test_ft_newface_sillyslot(void)
{
	FT_Face face;
	/* attempt to load a non-existant slot */
	fterr=FT_New_Face(ftlibrary, "/usr/share/fonts/TTF/Vera.ttf", 5, &face);
	/* failure is expected */
	TEST_ASSERT(fterr!=0);
}

TestRef TEST_FT_New_Face(void)
{
	EMB_UNIT_TESTFIXTURES(fixtures)
	{
		new_TestFixture("noexistfile", test_ft_newface_noexistfile),
		new_TestFixture("ok", test_ft_newface_ok),
		new_TestFixture("sillyslot", test_ft_newface_sillyslot),
	};
	EMB_UNIT_TESTCALLER(SetNewFaceTest, "FT_New_Face", setUp, tearDown, fixtures);

	/*lint -save -e(740) */
	return (TestRef) & SetNewFaceTest;
	/*lint -restore */
}

