/***************************************************************************/
/*                                                                         */
/*  ft2test/ft_sfnt_name.c                                                 */
/*                                                                         */
/*    test fixtures for FT_Get_Sfnt_Name*                                  */
/*                                                                         */
/*  Copyright 2005 by David Somers                                         */
/*                                                                         */
/*  This file is part of the FreeType project, and may only be used,       */
/*  modified, and distributed under the terms of the FreeType project      */
/*  license, LICENSE.TXT.  By continuing to use, modify, or distribute     */
/*  this file you indicate that you have read the license and              */
/*  understand and accept it fully.                                        */
/*                                                                         */
/***************************************************************************/

#include <ft2build.h>
#include FT_FREETYPE_H

#include FT_SFNT_NAMES_H

#include <embUnit/embUnit.h>

FT_Library ftlibrary;
FT_Error fterr;
FT_Face ftface;

static void setUp(void)
{
	FT_Init_FreeType(&ftlibrary);
	fterr=FT_New_Face(ftlibrary, "/usr/share/fonts/TTF/Vera.ttf", 0, &ftface);
}

static void tearDown(void)
{
	FT_Done_Face(ftface);
	FT_Done_FreeType(ftlibrary);
}

void test_init(void)
{
	TEST_ASSERT(fterr==0);
}

void test_ft_get_sfnt_name_count_ok(void)
{
	FT_UInt nNameCount;
	nNameCount=FT_Get_Sfnt_Name_Count(ftface);
	TEST_ASSERT_EQUAL_INT(22, nNameCount);
}

void test_ft_get_sfnt_name(void)
{
	FT_UInt i;
	FT_SfntName sfntName;
	
	FT_SfntName expected[22]=
	{	{ 1,0,0,0,NULL,58},
		{ 1,0,0,1,NULL,19},
		{ 1,0,0,2,NULL,5},
		{ 1,0,0,3,NULL,19},
		{ 1,0,0,4,NULL,19},
		{ 1,0,0,5,NULL,12},
		{ 1,0,0,6,NULL,23},
		{ 1,0,0,7,NULL,48},
		{ 1,0,0,8,NULL,14},
		{ 1,0,0,11,NULL,24},
		{ 1,0,0,13,NULL,2323},
		{ 3,1,1033,0,NULL,116},
		{ 3,1,1033,1,NULL,38},
		{ 3,1,1033,2,NULL,10},
		{ 3,1,1033,3,NULL,38},
		{ 3,1,1033,4,NULL,38},
		{ 3,1,1033,5,NULL,24},
		{ 3,1,1033,6,NULL,46},
		{ 3,1,1033,7,NULL,96},
		{ 3,1,1033,8,NULL,28},
		{ 3,1,1033,11,NULL,48},
		{ 3,1,1033,13,NULL,4646}
	};	
	
	for (i=0; i<22; i++)
	{
		fterr=FT_Get_Sfnt_Name(ftface, i, &sfntName);
		TEST_ASSERT(fterr==0);
		
		TEST_ASSERT_EQUAL_INT(expected[i].platform_id, sfntName.platform_id);
		TEST_ASSERT_EQUAL_INT(expected[i].encoding_id, sfntName.encoding_id);
		TEST_ASSERT_EQUAL_INT(expected[i].language_id, sfntName.language_id);
		TEST_ASSERT_EQUAL_INT(expected[i].name_id, sfntName.name_id);
		TEST_ASSERT_EQUAL_INT(expected[i].string_len, sfntName.string_len);
	}
}

TestRef TEST_FT_Sfnt_Name(void)
{
	EMB_UNIT_TESTFIXTURES(fixtures)
	{
		new_TestFixture("init", test_init),
		new_TestFixture("countok", test_ft_get_sfnt_name_count_ok),
		new_TestFixture("name content", test_ft_get_sfnt_name),
	};
	EMB_UNIT_TESTCALLER(SetSfntNameTest, "FT_Sfnt_Name", setUp, tearDown, fixtures);

	/*lint -save -e(740) */
	return (TestRef) & SetSfntNameTest;
	/*lint -restore */
}
